var __defProp = Object.defineProperty;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues = (a, b) => {
  for (var prop in b ||= {})
    if (__hasOwnProp.call(b, prop))
      __defNormalProp(a, prop, b[prop]);
  if (__getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(b)) {
      if (__propIsEnum.call(b, prop))
        __defNormalProp(a, prop, b[prop]);
    }
  return a;
};

// src/select.tsx
import classNames from "classnames";
import React, { Fragment, memo } from "react";
import { Listbox, Transition } from "@headlessui/react";
import {
  CheckIcon,
  ChevronDownIcon,
  XMarkIcon
} from "@heroicons/react/20/solid";
function Select({
  className,
  options,
  selectedOption,
  selectedOptions,
  onChange,
  multiple,
  placeholder,
  isLoading,
  filter,
  resetButton = true
}) {
  const selectedValue = multiple ? selectedOptions : selectedOption;
  const selectedLabel = multiple ? selectedOptions == null ? void 0 : selectedOptions.map((x) => x.label).join(", ") : selectedOption == null ? void 0 : selectedOption.label;
  return /* @__PURE__ */ React.createElement(
    Listbox,
    {
      value: selectedValue || null,
      onChange,
      multiple,
      as: "div",
      className: classNames("relative", className)
    },
    /* @__PURE__ */ React.createElement(
      Listbox.Button,
      {
        className: classNames(
          "relative form-control h-9 cursor-default py-2 pl-3 pr-10 text-left text-sm",
          filter ? "form-filter" : ""
        )
      },
      /* @__PURE__ */ React.createElement(
        "span",
        {
          title: selectedLabel,
          className: classNames(
            "block truncate",
            selectedLabel ? "" : "text-secondary-500"
          )
        },
        selectedLabel || placeholder
      ),
      (!resetButton || !selectedLabel) && /* @__PURE__ */ React.createElement("span", { className: "pointer-events-none absolute inset-y-0 right-2 flex items-center" }, /* @__PURE__ */ React.createElement(
        ChevronDownIcon,
        {
          className: "h-5 w-5 text-secondary-500",
          "aria-hidden": "true"
        }
      ))
    ),
    resetButton && selectedLabel && /* @__PURE__ */ React.createElement(
      "button",
      {
        type: "button",
        className: "absolute z-10 right-2.5 inset-y-0 my-auto h-5 px-0.5 rounded hover:bg-secondary-100 active:bg-secondary-200 focus:outline-none focus-visible:ring-2 focus-visible:ring-primary-500",
        onClick: () => {
          if (multiple) {
            onChange([]);
          } else {
            onChange(null);
          }
        }
      },
      /* @__PURE__ */ React.createElement(
        XMarkIcon,
        {
          className: "h-4 w-4 text-secondary-500",
          "aria-hidden": "true"
        }
      )
    ),
    /* @__PURE__ */ React.createElement(
      Transition,
      {
        as: Fragment,
        leave: "transition ease-in duration-100",
        leaveFrom: "opacity-100",
        leaveTo: "opacity-0"
      },
      /* @__PURE__ */ React.createElement(Listbox.Options, { className: "absolute z-40 mt-1 w-full rounded-md bg-white py-1 shadow-lg ring-1 ring-black ring-opacity-5 focus:outline-none text-sm" }, options.length === 0 || isLoading ? /* @__PURE__ */ React.createElement("div", { className: "relative cursor-default select-none py-2 px-4 text-secondary-700" }, isLoading ? "Loading..." : "No options") : /* @__PURE__ */ React.createElement("div", { className: "overflow-auto max-h-60" }, options.map((option) => /* @__PURE__ */ React.createElement(
        Listbox.Option,
        {
          key: option.value,
          className: ({ active }) => `relative cursor-default select-none py-2 pl-10 pr-4 ${active ? "bg-primary-100 text-primary-900" : "text-secondary-900"}`,
          value: option
        },
        ({ selected }) => /* @__PURE__ */ React.createElement(React.Fragment, null, /* @__PURE__ */ React.createElement(
          "span",
          {
            className: `block truncate ${selected && selectedValue ? "font-medium" : "font-normal"}`
          },
          option.label
        ), selected && selectedValue ? /* @__PURE__ */ React.createElement("span", { className: "absolute inset-y-0 left-0 flex items-center pl-3 text-primary-600" }, /* @__PURE__ */ React.createElement(CheckIcon, { className: "h-5 w-5", "aria-hidden": "true" })) : null)
      ))))
    )
  );
}
var select_default = memo(Select);

// src/searchSelect.tsx
import classNames2 from "classnames";
import React2, { Fragment as Fragment2, memo as memo2, useState } from "react";
import { Combobox, Transition as Transition2 } from "@headlessui/react";
import {
  CheckIcon as CheckIcon2,
  ChevronDownIcon as ChevronDownIcon2,
  XMarkIcon as XMarkIcon2,
  MagnifyingGlassIcon
} from "@heroicons/react/20/solid";
function SearchSelect({
  className,
  options,
  selectedOption,
  selectedOptions,
  onChange,
  multiple,
  placeholder,
  isLoading,
  filter,
  resetButton = true
}) {
  const [searchQuery, setSearchQuery] = useState("");
  const selectedValue = multiple ? selectedOptions : selectedOption;
  const selectedLabel = multiple ? selectedOptions == null ? void 0 : selectedOptions.map((x) => x.label).join(", ") : selectedOption == null ? void 0 : selectedOption.label;
  const searchString = searchQuery.toLowerCase().replace(/\s+/g, "");
  const currentOptions = searchQuery === "" ? options : options.filter(
    (x) => x.label.toLowerCase().replace(/\s+/g, "").includes(searchString)
  );
  return /* @__PURE__ */ React2.createElement(
    Combobox,
    {
      value: selectedValue || null,
      onChange,
      multiple,
      nullable: true,
      as: "div",
      className: classNames2("relative", className)
    },
    /* @__PURE__ */ React2.createElement(Combobox.Button, { as: "div" }, /* @__PURE__ */ React2.createElement(
      "button",
      {
        type: "button",
        className: classNames2(
          "relative form-control h-9 cursor-default py-2 pl-3 pr-10 text-left text-sm",
          filter ? "form-filter" : ""
        )
      },
      /* @__PURE__ */ React2.createElement(
        "span",
        {
          title: selectedLabel,
          className: classNames2(
            "block truncate",
            selectedLabel ? "" : "text-secondary-500"
          )
        },
        selectedLabel || placeholder
      ),
      (!resetButton || !selectedLabel) && /* @__PURE__ */ React2.createElement("span", { className: "pointer-events-none absolute inset-y-0 right-0 flex items-center pr-2" }, /* @__PURE__ */ React2.createElement(
        ChevronDownIcon2,
        {
          className: "h-5 w-5 text-secondary-500",
          "aria-hidden": "true"
        }
      ))
    )),
    resetButton && selectedLabel && /* @__PURE__ */ React2.createElement(
      "button",
      {
        type: "button",
        className: "absolute z-10 right-2.5 inset-y-0 my-2 px-0.5 rounded hover:bg-secondary-100 active:bg-secondary-200 focus:outline-none focus-visible:ring-2 focus-visible:ring-primary-500",
        onClick: () => {
          if (multiple) {
            onChange([]);
          } else {
            onChange(null);
          }
        }
      },
      /* @__PURE__ */ React2.createElement(
        XMarkIcon2,
        {
          className: "h-4 w-4 text-secondary-500",
          "aria-hidden": "true"
        }
      )
    ),
    /* @__PURE__ */ React2.createElement(
      Transition2,
      {
        as: Fragment2,
        leave: "transition ease-in duration-100",
        leaveFrom: "opacity-100",
        leaveTo: "opacity-0",
        afterLeave: () => {
          setSearchQuery("");
        }
      },
      /* @__PURE__ */ React2.createElement(Combobox.Options, { className: "absolute z-40 mt-1 w-full rounded-md bg-white py-1 shadow-lg ring-1 ring-black ring-opacity-5 focus:outline-none text-sm" }, !isLoading && /* @__PURE__ */ React2.createElement("div", { className: "relative" }, /* @__PURE__ */ React2.createElement(
        MagnifyingGlassIcon,
        {
          className: "pointer-events-none absolute top-3.5 left-4 h-5 w-5 text-secondary-400",
          "aria-hidden": "true"
        }
      ), /* @__PURE__ */ React2.createElement(
        Combobox.Input,
        {
          type: "search",
          placeholder: "Search...",
          className: "h-12 w-full bottom-0 border-transparent pl-11 pr-4 text-secondary-800 placeholder-secondary-400 text-sm focus:border-none focus:outline-none focus:ring-0 focus:shadow-none",
          displayValue: () => searchQuery,
          onChange: (event) => {
            setSearchQuery(event.target.value);
          }
        }
      )), currentOptions.length === 0 || isLoading ? /* @__PURE__ */ React2.createElement("div", { className: "relative cursor-default select-none py-2 px-4 text-secondary-700" }, isLoading ? "Loading..." : "No options") : /* @__PURE__ */ React2.createElement("div", { className: "overflow-auto max-h-60" }, currentOptions.map((option) => /* @__PURE__ */ React2.createElement(
        Combobox.Option,
        {
          key: option.value,
          className: ({ active }) => `relative cursor-default select-none py-2 pl-10 pr-4 ${active ? "bg-primary-100 text-primary-900" : "text-secondary-900"}`,
          value: option
        },
        ({ selected }) => /* @__PURE__ */ React2.createElement(React2.Fragment, null, /* @__PURE__ */ React2.createElement(
          "span",
          {
            className: `block truncate ${selected && selectedValue ? "font-medium" : "font-normal"}`
          },
          option.label
        ), selected && selectedValue ? /* @__PURE__ */ React2.createElement("span", { className: "absolute inset-y-0 left-0 flex items-center pl-3 text-primary-600" }, /* @__PURE__ */ React2.createElement(CheckIcon2, { className: "h-5 w-5", "aria-hidden": "true" })) : null)
      ))))
    )
  );
}
var searchSelect_default = memo2(SearchSelect);

// src/combobox.tsx
import React3, { memo as memo3 } from "react";
function Combobox2(props) {
  if (props.options.length > 6) {
    return /* @__PURE__ */ React3.createElement(searchSelect_default, __spreadValues({}, props));
  }
  return /* @__PURE__ */ React3.createElement(select_default, __spreadValues({}, props));
}
var combobox_default = memo3(Combobox2);

// src/autocomplete.tsx
import classNames3 from "classnames";
import React4, { Fragment as Fragment3, memo as memo4 } from "react";
import { Combobox as Combobox3, Transition as Transition3 } from "@headlessui/react";
import { CheckIcon as CheckIcon3, XMarkIcon as XMarkIcon3 } from "@heroicons/react/20/solid";
function Autocomplete({
  className,
  options,
  selectedOption,
  onChange,
  placeholder,
  isLoading,
  filter,
  searchQuery,
  onSearch,
  minQueryLength = 2,
  resetButton = true
}) {
  const selectedValue = selectedOption;
  const selectedLabel = selectedOption == null ? void 0 : selectedOption.label;
  const emptyMessage = searchQuery.length < minQueryLength ? `Type at least ${minQueryLength} symbols` : "Nothing found";
  const showOptions = options.length > 0 && !isLoading && searchQuery.length >= minQueryLength;
  return /* @__PURE__ */ React4.createElement(
    Combobox3,
    {
      value: selectedValue,
      onChange,
      nullable: true,
      as: "div",
      className: classNames3("relative", className)
    },
    /* @__PURE__ */ React4.createElement(
      Combobox3.Input,
      {
        placeholder: selectedLabel || placeholder,
        className: classNames3(
          "relative form-control h-9 cursor-default py-2 pl-3 pr-10 text-left text-sm truncate",
          filter ? "form-filter" : "",
          selectedLabel ? "placeholder-secondary-800" : "placeholder-secondary-500"
        ),
        displayValue: () => searchQuery,
        onChange: ({ target }) => {
          const { value } = target;
          onSearch(value, value.length >= minQueryLength);
        }
      }
    ),
    resetButton && selectedValue && /* @__PURE__ */ React4.createElement(
      "button",
      {
        type: "button",
        className: "absolute z-10 right-2.5 inset-y-0 my-2 px-0.5 rounded hover:bg-secondary-100 active:bg-secondary-200 focus:outline-none focus-visible:ring-2 focus-visible:ring-primary-500",
        onClick: () => {
          onChange(null);
        }
      },
      /* @__PURE__ */ React4.createElement(
        XMarkIcon3,
        {
          className: "h-4 w-4 text-secondary-500",
          "aria-hidden": "true"
        }
      )
    ),
    /* @__PURE__ */ React4.createElement(
      Transition3,
      {
        as: Fragment3,
        leave: "transition ease-in duration-100",
        leaveFrom: "opacity-100",
        leaveTo: "opacity-0",
        afterLeave: () => {
          onSearch("", false);
        }
      },
      /* @__PURE__ */ React4.createElement(Combobox3.Options, { className: "absolute z-40 mt-1 w-full rounded-md bg-white py-1 shadow-lg ring-1 ring-black ring-opacity-5 focus:outline-none text-sm" }, !showOptions ? /* @__PURE__ */ React4.createElement("div", { className: "relative cursor-default select-none py-2 px-4 text-secondary-700" }, isLoading ? "Loading..." : emptyMessage) : /* @__PURE__ */ React4.createElement("div", { className: "overflow-auto max-h-60" }, options.map((option) => /* @__PURE__ */ React4.createElement(
        Combobox3.Option,
        {
          key: option.value,
          className: ({ active }) => `relative cursor-default select-none py-2 pl-10 pr-4 ${active ? "bg-primary-100 text-primary-900" : "text-secondary-900"}`,
          value: option
        },
        ({ selected }) => /* @__PURE__ */ React4.createElement(React4.Fragment, null, /* @__PURE__ */ React4.createElement(
          "span",
          {
            className: `block truncate ${selected && selectedValue ? "font-medium" : "font-normal"}`
          },
          option.label
        ), selected && selectedValue ? /* @__PURE__ */ React4.createElement("span", { className: "absolute inset-y-0 left-0 flex items-center pl-3 text-primary-600" }, /* @__PURE__ */ React4.createElement(CheckIcon3, { className: "h-5 w-5", "aria-hidden": "true" })) : null)
      ))))
    )
  );
}
var autocomplete_default = memo4(Autocomplete);

// src/index.tsx
var src_default = select_default;
export {
  autocomplete_default as Autocomplete,
  combobox_default as Combobox,
  searchSelect_default as SearchSelect,
  select_default as Select,
  src_default as default
};
